==> rapidsvn_0.9.4.orig.tar.gz: rapidsvn-0.9.4/src/hist_entries.cpp <==
/*
 * ====================================================================
 * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program (in the file GPL.txt); if not, write to 
 * the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 *
 * This software consists of voluntary contributions made by many
 * individuals.  For exact contribution history, see the revision
 * history and logs, available at http://rapidsvn.tigris.org/.
 * ====================================================================
 */


// app
#include "hist_entries.hpp"


const wxChar HISTORY_COMMIT_LOG[] = wxT("History/CommitLog");

const wxChar HISTORY_REPOSITORY[] = wxT("History/Repositories");

const wxChar HISTORY_WORKING_DIRECTORY[] = wxT("History/WorkingDirectories");

/* -----------------------------------------------------------------
 * local variables:
 * eval: (load-file "../rapidsvn-dev.el")
 * end:
 */

==> rapidsvn_0.9.6.orig.tar.gz: rapidsvn-0.9.6/src/hist_entries.cpp <==
/*
 * ====================================================================
 * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program (in the file GPL.txt); if not, write to 
 * the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 *
 * This software consists of voluntary contributions made by many
 * individuals.  For exact contribution history, see the revision
 * history and logs, available at http://rapidsvn.tigris.org/.
 * ====================================================================
 */


// app
#include "hist_entries.hpp"


const wxChar HISTORY_COMMIT_LOG[] = wxT("History/CommitLog");

const wxChar HISTORY_REPOSITORY[] = wxT("History/Repositories");

const wxChar HISTORY_WORKING_DIRECTORY[] = wxT("History/WorkingDirectories");

const wxChar HISTORY_COPYMOVE_DESTINATION [] = wxT("History/CopyMoveDestination");

const wxChar HISTORY_DIFF_URL [] = wxT("History/DiffUrl");

/* -----------------------------------------------------------------
 * local variables:
 * eval: (load-file "../rapidsvn-dev.el")
 * end:
 */
